==> agschat-0.0.19.tar.gz: lib/src/view/widgets/comman.dart <==
import 'package:agschat/src/helper/images.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class Common {
  // static getSnackToast({
  //   title = "Error",
  //   message = '',
  //   snackPosition: SnackPosition.TOP,
  //   backgroundColor = Colors.black,
  //   colorText = Colors.white,
  //   Widget? icon,
  //   Duration? duration,
  //   Function? onTapSnackBar,
  //   Function? onTapButton,
  //   bool withButton = false,
  //   buttonText = 'Ok',
  //   Function? onDismissed,
  // }) {
  //   Get.snackbar(
  //     title,
  //     message,
  //     mainButton: withButton
  //         ? TextButton(
  //             onPressed: () {
  //               if (onTapButton != null) onTapButton();
  //             },
  //             child: Text(buttonText))
  //         : null,
  //     onTap: (tap) {
  //       if (onTapSnackBar != null) onTapSnackBar(tap);
  //     },
  //     duration: const Duration(milliseconds: 700),
  //     snackPosition: snackPosition,
  //     backgroundColor: backgroundColor,
  //     icon: icon,
  //     colorText: colorText,
  //     isDismissible: true,
  //     snackbarStatus: (status) {
  //       print(status);
  //       if (status == SnackbarStatus.CLOSED) {
  //         if (onDismissed != null) onDismissed();
  //       }
  //     },
  //   );
  // }
  static getSnackToast(
    context, {
    title = "Error",
    message = '',
    snackPosition: SnackPosition.TOP,
    backgroundColor = Colors.black,
    colorText = Colors.white,
    Widget? icon,
    Duration? duration,
    Function? onTapSnackBar,
    Function? onTapButton,
    bool withButton = false,
    buttonText = 'Ok',
    Function? onDismissed,
  }) {
    // Get.snackbar(
    //   title,
    //   message,
    //   mainButton: withButton
    //       ? TextButton(
    //           onPressed: () {
    //             if (onTapButton != null) onTapButton();
    //           },
    //           child: Text(buttonText))
    //       : null,
    //   onTap: (tap) {
    //     if (onTapSnackBar != null) onTapSnackBar(tap);
    //   },
    //   duration: const Duration(milliseconds: 700),
    //   snackPosition: snackPosition,
    //   backgroundColor: backgroundColor,
    //   icon: icon,
    //   colorText: colorText,
    //   isDismissible: true,
    //   snackbarStatus: (status) {
    //     print(status);
    //     if (status == SnackbarStatus.CLOSED) {
    //       if (onDismissed != null) onDismissed();
    //     }
    //   },
    // );
    final snackBar = SnackBar(
      content: Text(message),
      duration: const Duration(milliseconds: 700),
      backgroundColor: backgroundColor,
      action: SnackBarAction(
        label: title,
        onPressed: () {
          // Some code to undo the change.
        },
      ),
    );
    // Find the ScaffoldMessenger in the widget tree
    // and use it to show a SnackBar.
    ScaffoldMessenger.of(context).showSnackBar(snackBar);
  }

  static profileNetworkImage({
    height = 50.0,
    width = 50.0,
    isShowBorder = false,
    borderWidth = 1.5,
    showBoxShadow = false,
    borderRadius = 40.0,
    backgroundColor,
    placeHolder = ImageResource.profilePlaceHolder,
    imageUrl = "",
  }) {
    return Container(
      height: height,
      width: width,
      decoration: BoxDecoration(
          color: backgroundColor ?? Colors.black12,
          shape: BoxShape.circle,
          border: Border.all(
              color: isShowBorder ? Colors.white : Colors.transparent,
              width: borderWidth),
          boxShadow: showBoxShadow
              ? [
                  BoxShadow(
                    color: const Color(0xff000000).withOpacity(0.10),
                    blurRadius: 10.0,
                    spreadRadius: 1.0,
                  )
                ]
              : []),
      child: ClipRRect(
        borderRadius: BorderRadius.circular(borderRadius),
        child: CachedNetworkImage(
          fadeInDuration: const Duration(milliseconds: 250),
          imageUrl: imageUrl == "" || imageUrl == null ? "" : imageUrl,
          errorWidget: (context, url, error) => Opacity(
            opacity: 0.9,
            child: ClipRRect(
              borderRadius: BorderRadius.circular(30.0),
              child: Image.asset(
                placeHolder,
                height: height,
                width: width,
              ),
            ),
          ),
          fit: BoxFit.cover,
          placeholder: ((context, String s) => Image.asset(
                placeHolder,
                height: height,
                width: width,
              )),
        ),
      ),
    );
  }
}

==> agschat-0.0.29.tar.gz: lib/src/view/widgets/comman.dart <==
import 'package:agschat/src/helper/images.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class Common {
  // static getSnackToast({
  //   title = "Error",
  //   message = '',
  //   snackPosition: SnackPosition.TOP,
  //   backgroundColor = Colors.black,
  //   colorText = Colors.white,
  //   Widget? icon,
  //   Duration? duration,
  //   Function? onTapSnackBar,
  //   Function? onTapButton,
  //   bool withButton = false,
  //   buttonText = 'Ok',
  //   Function? onDismissed,
  // }) {
  //   Get.snackbar(
  //     title,
  //     message,
  //     mainButton: withButton
  //         ? TextButton(
  //             onPressed: () {
  //               if (onTapButton != null) onTapButton();
  //             },
  //             child: Text(buttonText))
  //         : null,
  //     onTap: (tap) {
  //       if (onTapSnackBar != null) onTapSnackBar(tap);
  //     },
  //     duration: const Duration(milliseconds: 700),
  //     snackPosition: snackPosition,
  //     backgroundColor: backgroundColor,
  //     icon: icon,
  //     colorText: colorText,
  //     isDismissible: true,
  //     snackbarStatus: (status) {
  //       print(status);
  //       if (status == SnackbarStatus.CLOSED) {
  //         if (onDismissed != null) onDismissed();
  //       }
  //     },
  //   );
  // }
  static getSnackToast(
    context, {
    title = "Error",
    message = '',
    snackPosition: SnackPosition.TOP,
    backgroundColor = Colors.black,
    colorText = Colors.white,
    Widget? icon,
    Duration? duration,
    Function? onTapSnackBar,
    Function? onTapButton,
    bool withButton = false,
    buttonText = 'Ok',
    Function? onDismissed,
  }) {
    // Get.snackbar(
    //   title,
    //   message,
    //   mainButton: withButton
    //       ? TextButton(
    //           onPressed: () {
    //             if (onTapButton != null) onTapButton();
    //           },
    //           child: Text(buttonText))
    //       : null,
    //   onTap: (tap) {
    //     if (onTapSnackBar != null) onTapSnackBar(tap);
    //   },
    //   duration: const Duration(milliseconds: 700),
    //   snackPosition: snackPosition,
    //   backgroundColor: backgroundColor,
    //   icon: icon,
    //   colorText: colorText,
    //   isDismissible: true,
    //   snackbarStatus: (status) {
    //     print(status);
    //     if (status == SnackbarStatus.CLOSED) {
    //       if (onDismissed != null) onDismissed();
    //     }
    //   },
    // );
    final snackBar = SnackBar(
      content: Text(message),
      duration: const Duration(milliseconds: 700),
      backgroundColor: backgroundColor,
      action: SnackBarAction(
        label: title,
        onPressed: () {
          // Some code to undo the change.
        },
      ),
    );
    // Find the ScaffoldMessenger in the widget tree
    // and use it to show a SnackBar.
    ScaffoldMessenger.of(context).showSnackBar(snackBar);
  }

  static profileNetworkImage({
    height = 50.0,
    width = 50.0,
    isShowBorder = false,
    borderWidth = 1.5,
    showBoxShadow = false,
    borderRadius = 40.0,
    backgroundColor,
    placeHolder = ImageResource.profilePlaceHolder,
    imageUrl = "",
  }) {
    return Container(
      height: height,
      width: width,
      decoration: BoxDecoration(
          color: backgroundColor ?? Colors.black12,
          shape: BoxShape.circle,
          border: Border.all(
              color: isShowBorder ? Colors.white : Colors.transparent,
              width: borderWidth),
          boxShadow: showBoxShadow
              ? [
                  BoxShadow(
                    color: const Color(0xff000000).withOpacity(0.10),
                    blurRadius: 10.0,
                    spreadRadius: 1.0,
                  )
                ]
              : []),
      child: ClipRRect(
        borderRadius: BorderRadius.circular(borderRadius),
        child: CachedNetworkImage(
          fadeInDuration: const Duration(milliseconds: 250),
          imageUrl: imageUrl == "" || imageUrl == null ? "" : imageUrl,
          errorWidget: (context, url, error) => Opacity(
            opacity: 0.9,
            child: ClipRRect(
              borderRadius: BorderRadius.circular(30.0),
              child: Image.asset(
                placeHolder,
                height: height,
                width: width,
                package: 'agschat',
              ),
            ),
          ),
          fit: BoxFit.cover,
          placeholder: ((context, String s) => Image.asset(placeHolder,
              height: height, width: width, package: 'agschat')),
        ),
      ),
    );
  }
}
